@@ -35,7 +35,7 @@ class GUI : public QMainWindow
 	Q_OBJECT
 
 public:
-	GUI(QWidget *parent = 0);
+	GUI();
 	~GUI();
 
 	bool openFile(const QString &fileName);
@@ -47,6 +47,8 @@ private slots:
 	void createMapMenu();
 	void showMapWidget(bool show);
 	void showStatusbar(bool show);
+	void onProcessStarted();
+	void onProcessReady();
 #endif
 	void about();
 	void keys();
@@ -60,7 +62,6 @@ private slots:
 	void reloadFile();
 	void openPOIFile();
 	void closePOIFiles();
-	void showMap(bool show);
 	void showGraphs(bool show);
 	void showGraphGrids(bool show);
 	void showToolbars(bool show);
@@ -212,8 +213,8 @@ private:
 
 	FileBrowser *_browser;
 	QList<QString> _files;
-	Map *_currentMap;
 
+	Map *_map;
 	int _trackCount;
 	int _routeCount;
 	int _waypointCount;
