@@ -1,12 +1,13 @@
 #include <QGraphicsView>
 #include <QGraphicsScene>
 #include <QWheelEvent>
+#include <QSysInfo>
 #include "opengl.h"
-#include "rd.h"
-#include "wgs84.h"
+#include "misc.h"
 #include "poi.h"
 #include "data.h"
 #include "map.h"
+#include "emptymap.h"
 #include "trackitem.h"
 #include "routeitem.h"
 #include "waypointitem.h"
@@ -14,59 +15,9 @@
 #include "pathview.h"
 
 
-#define ZOOM_MAX      18
-#define ZOOM_MIN      3
 #define MARGIN        10.0
 #define SCALE_OFFSET  7
 
-static QPoint mercator2tile(const QPointF &m, int z)
-{
-	QPoint tile;
-
-	tile.setX((int)(floor((m.x() + 180.0) / 360.0 * (1<<z))));
-	tile.setY((int)(floor((1.0 - (m.y() / 180.0)) / 2.0 * (1<<z))));
-
-	return tile;
-}
-
-static QPointF tile2mercator(const QPoint &tile, int z)
-{
-	QPointF m;
-
-	m.setX(((360.0 * tile.x()) / (qreal)(1<<z)) - 180.0);
-	m.setY((1.0 - (2.0 * tile.y()) / (qreal)(1<<z)) * 180.0);
-
-	return m;
-}
-
-static int scale2zoom(qreal scale)
-{
-	int zoom = (int)log2(360.0/(scale * (qreal)Tile::size()));
-
-	if (zoom < ZOOM_MIN)
-		return ZOOM_MIN;
-	if (zoom > ZOOM_MAX)
-		return ZOOM_MAX;
-
-	return zoom;
-}
-
-qreal mapScale(int zoom)
-{
-	return ((360.0/(qreal)(1<<zoom))/(qreal)Tile::size());
-}
-
-static QRectF mapBounds()
-{
-	return QRectF(QPointF(-180, -180), QSizeF(360, 360));
-}
-
-static qreal zoom2resolution(int zoom, qreal y)
-{
-	return (WGS84_RADIUS * 2 * M_PI / Tile::size()
-	  * cos(2.0 * atan(exp(deg2rad(y))) - M_PI/2)) / (qreal)(1<<zoom);
-}
-
 static void unite(QRectF &rect, const QPointF &p)
 {
 	if (p.x() < rect.left())
@@ -79,16 +30,12 @@ static void unite(QRectF &rect, const QPointF &p)
 		rect.setTop(p.y());
 }
 
-static QRectF scaled(const QRectF &rect, qreal factor)
-{
-	return QRectF(QPointF(rect.left() * factor, rect.top() * factor),
-	  QSizeF(rect.width() * factor, rect.height() * factor));
-}
-
-
-PathView::PathView(QWidget *parent)
+PathView::PathView(Map *map, POI *poi, QWidget *parent)
 	: QGraphicsView(parent)
 {
+	Q_ASSERT(map != 0);
+	Q_ASSERT(poi != 0);
+
 	_scene = new QGraphicsScene(this);
 	setScene(_scene);
 	setCacheMode(QGraphicsView::CacheBackground);
@@ -102,13 +49,14 @@ PathView::PathView(QWidget *parent)
 	_mapScale = new ScaleItem();
 	_mapScale->setZValue(2.0);
 
-	_zoom = ZOOM_MAX;
-	_res = 1.0;
-	_map = 0;
-	_poi = 0;
+	_map = map;
+	_poi = poi;
+	connect(_map, SIGNAL(loaded()), this, SLOT(redraw()));
+	connect(_poi, SIGNAL(pointsChanged()), this, SLOT(updatePOI()));
 
 	_units = Metric;
 
+	_showMap = true;
 	_showTracks = true;
 	_showRoutes = true;
 	_showWaypoints = true;
@@ -124,7 +72,8 @@ PathView::PathView(QWidget *parent)
 
 	_plot = false;
 
-	_scene->setSceneRect(scaled(mapBounds(), 1.0 / mapScale(_zoom)));
+	_scene->setSceneRect(_map->bounds());
+	_res = _map->resolution(_scene->sceneRect().center());
 }
 
 PathView::~PathView()
@@ -140,19 +89,16 @@ PathItem *PathView::addTrack(const Track &track)
 		return 0;
 	}
 
-	TrackItem *ti = new TrackItem(track);
+	TrackItem *ti = new TrackItem(track, _map);
 	_tracks.append(ti);
 	_tr |= ti->path().boundingRect();
-	_zoom = scale2zoom(contentsScale());
-	ti->setScale(1.0/mapScale(_zoom));
 	ti->setColor(_palette.nextColor());
 	ti->setWidth(_trackWidth);
 	ti->setStyle(_trackStyle);
 	ti->setVisible(_showTracks);
 	_scene->addItem(ti);
 
-	if (_poi)
-		addPOI(_poi->points(ti));
+	addPOI(_poi->points(ti->path()));
 
 	return ti;
 }
@@ -164,11 +110,9 @@ PathItem *PathView::addRoute(const Route &route)
 		return 0;
 	}
 
-	RouteItem *ri = new RouteItem(route);
+	RouteItem *ri = new RouteItem(route, _map);
 	_routes.append(ri);
 	_rr |= ri->path().boundingRect();
-	_zoom = scale2zoom(contentsScale());
-	ri->setScale(1.0/mapScale(_zoom));
 	ri->setColor(_palette.nextColor());
 	ri->setWidth(_routeWidth);
 	ri->setStyle(_routeStyle);
@@ -177,61 +121,52 @@ PathItem *PathView::addRoute(const Route &route)
 	ri->showWaypointLabels(_showWaypointLabels);
 	_scene->addItem(ri);
 
-	if (_poi)
-		addPOI(_poi->points(ri));
+	addPOI(_poi->points(ri->path()));
 
 	return ri;
 }
 
 void PathView::addWaypoints(const QList<Waypoint> &waypoints)
 {
-	qreal scale = mapScale(_zoom);
-
 	for (int i = 0; i < waypoints.count(); i++) {
 		const Waypoint &w = waypoints.at(i);
 
-		WaypointItem *wi = new WaypointItem(w);
+		WaypointItem *wi = new WaypointItem(w, _map);
 		_waypoints.append(wi);
-		updateWaypointsBoundingRect(wi->coordinates());
-		wi->setScale(1.0/scale);
+		Coordinates c = wi->waypoint().coordinates();
+		updateWaypointsBoundingRect(QPointF(c.lon(), c.lat()));
 		wi->setZValue(1);
 		wi->showLabel(_showWaypointLabels);
 		wi->setVisible(_showWaypoints);
 		_scene->addItem(wi);
 	}
 
-	if (_poi)
-		addPOI(_poi->points(waypoints));
-
-	_zoom = scale2zoom(contentsScale());
+	addPOI(_poi->points(waypoints));
 }
 
 QList<PathItem *> PathView::loadData(const Data &data)
 {
 	QList<PathItem *> paths;
-	int zoom = _zoom;
-
+	qreal scale = _map->zoom();
 
 	for (int i = 0; i < data.tracks().count(); i++)
 		paths.append(addTrack(*(data.tracks().at(i))));
-
 	for (int i = 0; i < data.routes().count(); i++)
 		paths.append(addRoute(*(data.routes().at(i))));
-
 	addWaypoints(data.waypoints());
 
 	if (_tracks.empty() && _routes.empty() && _waypoints.empty())
 		return paths;
 
-	if (_zoom < zoom)
-		rescale(_zoom);
+	if (mapScale() != scale)
+		rescale();
 	else
 		updatePOIVisibility();
 
-	QPointF center = contentsCenter();
+	QPointF center = contentCenter();
 	centerOn(center);
 
-	_res = zoom2resolution(_zoom, -(center.y() * mapScale(_zoom)));
+	_res = _map->resolution(center);
 	_mapScale->setResolution(_res);
 	if (_mapScale->scene() != _scene)
 		_scene->addItem(_mapScale);
@@ -252,33 +187,25 @@ void PathView::updateWaypointsBoundingRect(const QPointF &wp)
 		unite(_wr, wp);
 }
 
-qreal PathView::contentsScale() const
+qreal PathView::mapScale() const
 {
 	QRectF br = _tr | _rr | _wr;
 	if (!br.isNull() && !_wp.isNull())
 		unite(br, _wp);
 
-	if (br.isNull())
-		return mapScale(ZOOM_MAX);
-
-	QPointF sc(br.width() / (viewport()->width() - MARGIN/2),
-	  br.height() / (viewport()->height() - MARGIN/2));
-
-	return qMax(sc.x(), sc.y());
+	return _map->zoomFit(viewport()->size() - QSize(MARGIN/2, MARGIN/2), br);
 }
 
-QPointF PathView::contentsCenter() const
+QPointF PathView::contentCenter() const
 {
 	QRectF br = _tr | _rr | _wr;
 	if (!br.isNull() && !_wp.isNull())
 		unite(br, _wp);
 
-	qreal scale = mapScale(_zoom);
-
 	if (br.isNull())
-		return _wp / scale;
+		return _map->ll2xy(_wp);
 	else
-		return scaled(br, 1.0/scale).center();
+		return _map->ll2xy(br.center());
 }
 
 void PathView::updatePOIVisibility()
@@ -302,25 +229,21 @@ void PathView::updatePOIVisibility()
 	}
 }
 
-void PathView::rescale(int zoom)
+void PathView::rescale()
 {
-	_zoom = zoom;
-	qreal scale = mapScale(zoom);
-
-	_scene->setSceneRect(scaled(mapBounds(), 1.0 / scale));
+	_scene->setSceneRect(_map->bounds());
+	resetCachedContent();
 
 	for (int i = 0; i < _tracks.size(); i++)
-		_tracks.at(i)->setScale(1.0/scale);
-
+		_tracks.at(i)->setMap(_map);
 	for (int i = 0; i < _routes.size(); i++)
-		_routes.at(i)->setScale(1.0/scale);
-
+		_routes.at(i)->setMap(_map);
 	for (int i = 0; i < _waypoints.size(); i++)
-		_waypoints.at(i)->setScale(1.0/scale);
+		_waypoints.at(i)->setMap(_map);
 
 	QHash<Waypoint, WaypointItem*>::const_iterator it;
 	for (it = _pois.constBegin(); it != _pois.constEnd(); it++)
-		it.value()->setScale(1.0/scale);
+		it.value()->setMap(_map);
 
 	updatePOIVisibility();
 }
@@ -336,16 +259,41 @@ void PathView::setPalette(const Palette &palette)
 		_routes.at(i)->setColor(_palette.nextColor());
 }
 
+void PathView::setMap(Map *map)
+{
+	_map->unload();
+	disconnect(_map, SIGNAL(loaded()), this, SLOT(redraw()));
+
+	_map = map;
+	_map->load();
+	connect(_map, SIGNAL(loaded()), this, SLOT(redraw()));
+
+	mapScale();
+	_scene->setSceneRect(_map->bounds());
+
+	for (int i = 0; i < _tracks.size(); i++)
+		_tracks.at(i)->setMap(map);
+	for (int i = 0; i < _routes.size(); i++)
+		_routes.at(i)->setMap(map);
+	for (int i = 0; i < _waypoints.size(); i++)
+		_waypoints.at(i)->setMap(map);
+
+	QPointF center = contentCenter();
+	centerOn(center);
+
+	_res = _map->resolution(center);
+	_mapScale->setResolution(_res);
+
+	resetCachedContent();
+}
+
 void PathView::setPOI(POI *poi)
 {
-	if (_poi)
-		disconnect(_poi, SIGNAL(pointsChanged()), this, SLOT(updatePOI()));
+	disconnect(_poi, SIGNAL(pointsChanged()), this, SLOT(updatePOI()));
+	connect(poi, SIGNAL(pointsChanged()), this, SLOT(updatePOI()));
 
 	_poi = poi;
 
-	if (_poi)
-		connect(_poi, SIGNAL(pointsChanged()), this, SLOT(updatePOI()));
-
 	updatePOI();
 }
 
@@ -359,13 +307,10 @@ void PathView::updatePOI()
 	}
 	_pois.clear();
 
-	if (!_poi)
-		return;
-
 	for (int i = 0; i < _tracks.size(); i++)
-		addPOI(_poi->points(_tracks.at(i)));
+		addPOI(_poi->points(_tracks.at(i)->path()));
 	for (int i = 0; i < _routes.size(); i++)
-		addPOI(_poi->points(_routes.at(i)));
+		addPOI(_poi->points(_routes.at(i)->path()));
 	addPOI(_poi->points(_waypoints));
 
 	updatePOIVisibility();
@@ -373,16 +318,13 @@ void PathView::updatePOI()
 
 void PathView::addPOI(const QVector<Waypoint> &waypoints)
 {
-	qreal scale = mapScale(_zoom);
-
 	for (int i = 0; i < waypoints.size(); i++) {
 		const Waypoint &w = waypoints.at(i);
 
 		if (_pois.contains(w))
 			continue;
 
-		WaypointItem *pi = new WaypointItem(w);
-		pi->setScale(1.0/scale);
+		WaypointItem *pi = new WaypointItem(w, _map);
 		pi->setZValue(1);
 		pi->showLabel(_showPOILabels);
 		pi->setVisible(_showPOI);
@@ -392,19 +334,6 @@ void PathView::addPOI(const QVector<Waypoint> &waypoints)
 	}
 }
 
-void PathView::setMap(Map *map)
-{
-	if (_map)
-		disconnect(_map, SIGNAL(loaded()), this, SLOT(redraw()));
-
-	_map = map;
-
-	if (_map)
-		connect(_map, SIGNAL(loaded()), this, SLOT(redraw()));
-
-	resetCachedContent();
-}
-
 void PathView::setUnits(enum Units units)
 {
 	_units = units;
@@ -428,45 +357,50 @@ void PathView::redraw()
 	resetCachedContent();
 }
 
-void PathView::zoom(int z, const QPoint &pos)
+void PathView::zoom(const QPoint &pos, const Coordinates &c)
 {
-	if (_tracks.isEmpty() && _routes.isEmpty() && _waypoints.isEmpty())
-		return;
-
 	QPoint offset = pos - viewport()->rect().center();
-	QPointF spos = mapToScene(pos);
 
-	qreal os = mapScale(_zoom);
-	_zoom = z;
+	rescale();
 
-	rescale(_zoom);
-
-	QPointF center = (spos * (os/mapScale(_zoom))) - offset;
+	QPointF center = _map->ll2xy(c) - offset;
 	centerOn(center);
 
-	_res = zoom2resolution(_zoom, -(center.y() * mapScale(_zoom)));
+	_res = _map->resolution(center);
 	_mapScale->setResolution(_res);
-
-	resetCachedContent();
 }
 
 void PathView::wheelEvent(QWheelEvent *event)
 {
-	int z = (event->delta() > 0) ?
-		qMin(_zoom + 1, ZOOM_MAX) : qMax(_zoom - 1, ZOOM_MIN);
+	qreal os, ns;
+	static int deg = 0;
 
-	zoom(z, event->pos());
+	deg += event->delta() / 8;
+	if (qAbs(deg) < 15)
+		return;
+	deg = 0;
+
+	os = _map->zoom();
+	Coordinates c = _map->xy2ll(mapToScene(event->pos()));
+
+	ns = (event->delta() > 0) ? _map->zoomIn() : _map->zoomOut();
+	if (ns != os)
+		zoom(event->pos(), c);
 }
 
 void PathView::mouseDoubleClickEvent(QMouseEvent *event)
 {
+	qreal os, ns;
+
 	if (event->button() != Qt::LeftButton && event->button() != Qt::RightButton)
 		return;
 
-	int z = (event->button() == Qt::LeftButton) ?
-		qMin(_zoom + 1, ZOOM_MAX) : qMax(_zoom - 1, ZOOM_MIN);
+	os = _map->zoom();
+	Coordinates c = _map->xy2ll(mapToScene(event->pos()));
 
-	zoom(z, event->pos());
+	ns = (event->button() == Qt::LeftButton) ? _map->zoomIn() : _map->zoomOut();
+	if (ns != os)
+		zoom(event->pos(), c);
 }
 #ifdef Q_WS_MAEMO_5
 void PathView::mousePressEvent(QMouseEvent *e)
@@ -478,36 +412,49 @@ void PathView::mousePressEvent(QMouseEvent *e)
 }
 void PathView::zoom_maemo(QString direction)
 {
-	int z = -1;
-	if (direction=="in") z = qMin(_zoom + 1, ZOOM_MAX);
-	else z = qMax(_zoom - 1, ZOOM_MIN);
-	if (z >= 0) zoom(z, QRect(QPoint(), size()).center());
+	qreal os, ns;
+
+	os = _map->zoom();
+	QPoint pos = QRect(QPoint(), viewport()->size()).center();
+	Coordinates c = _map->xy2ll(mapToScene(pos));
+	if (direction=="in") ns = _map->zoomIn();
+	else ns = _map->zoomOut();
+	if (ns != os)
+		zoom(pos, c);
 }
+void PathView::setRescale(bool rescale)
+{
+	_rescale=rescale;
+}
+
 #endif
 
 void PathView::keyPressEvent(QKeyEvent *event)
 {
-	int z = -1;
+	qreal os, ns;
+
+	os = _map->zoom();
+	QPoint pos = QRect(QPoint(), viewport()->size()).center();
+	Coordinates c = _map->xy2ll(mapToScene(pos));
 
 #ifdef Q_WS_MAEMO_5
 	if (event->key()==Qt::Key_F7)
-		z = qMin(_zoom + 1, ZOOM_MAX);
+		ns = _map->zoomIn();
 	else if (event->key()==Qt::Key_F8)
-		z = qMax(_zoom - 1, ZOOM_MIN);
-	else QWidget::keyPressEvent(event);
-	if (z >= 0)
-		zoom(z, QRect(QPoint(), size()).center());
+		ns = _map->zoomOut();
 #else
 	if (event->matches(QKeySequence::ZoomIn))
-		z = qMin(_zoom + 1, ZOOM_MAX);
-	if (event->matches(QKeySequence::ZoomOut))
-		z = qMax(_zoom - 1, ZOOM_MIN);
-
-	if (z >= 0)
-		zoom(z, QRect(QPoint(), size()).center());
-	else
-		QWidget::keyPressEvent(event);
+		ns = _map->zoomIn();
+	else if (event->matches(QKeySequence::ZoomOut))
+		ns = _map->zoomOut();
 #endif
+	else {
+		QWidget::keyPressEvent(event);
+		return;
+	}
+
+	if (ns != os)
+		zoom(pos, c);
 }
 
 void PathView::plot(QPainter *painter, const QRectF &target)
@@ -519,7 +466,7 @@ void PathView::plot(QPainter *painter, const QRectF &target)
 	orig = viewport()->rect();
 
 	if (orig.height() * (target.width() / target.height()) - orig.width() < 0) {
-		ratio = target.height()/target.width();
+		ratio = target.height() / target.width();
 		diff = (orig.width() * ratio) - orig.height();
 		adj = orig.adjusted(0, -diff/2, 0, diff/2);
 	} else {
@@ -530,6 +477,7 @@ void PathView::plot(QPainter *painter, const QRectF &target)
 
 	setUpdatesEnabled(false);
 	_plot = true;
+	_map->setBlockingMode(true);
 
 	QPointF pos = _mapScale->pos();
 	_mapScale->setPos(mapToScene(QPoint(adj.bottomRight() + QPoint(
@@ -540,6 +488,7 @@ void PathView::plot(QPainter *painter, const QRectF &target)
 
 	_mapScale->setPos(pos);
 
+	_map->setBlockingMode(false);
 	_plot = false;
 	setUpdatesEnabled(true);
 }
@@ -556,12 +505,8 @@ void PathView::clear()
 	_scene->clear();
 	_palette.reset();
 
-	_zoom = ZOOM_MAX;
-	_res = 1.0;
 	_tr = QRectF(); _rr = QRectF(); _wr = QRectF();
 	_wp = QPointF();
-
-	_scene->setSceneRect(scaled(mapBounds(), 1.0 / mapScale(_zoom)));
 }
 
 void PathView::showTracks(bool show)
@@ -607,6 +552,12 @@ void PathView::showRouteWaypoints(bool show)
 		_routes.at(i)->showWaypoints(show);
 }
 
+void PathView::showMap(bool show)
+{
+	_showMap = show;
+	resetCachedContent();
+}
+
 void PathView::showPOI(bool show)
 {
 	_showPOI = show;
@@ -670,54 +621,34 @@ void PathView::setRouteStyle(Qt::PenStyle style)
 
 void PathView::drawBackground(QPainter *painter, const QRectF &rect)
 {
-	if ((_tracks.isEmpty() && _routes.isEmpty() && _waypoints.isEmpty())
-	  || !_map) {
+	if (_showMap)
+		_map->draw(painter, rect);
+	else
 		painter->fillRect(rect, Qt::white);
-		return;
-	}
-
-	qreal scale = mapScale(_zoom);
-	QRectF rr(rect.topLeft() * scale, rect.size());
-	QPoint tile = mercator2tile(QPointF(rr.topLeft().x(), -rr.topLeft().y()),
-	  _zoom);
-	QPointF tm = tile2mercator(tile, _zoom);
-	QPoint tl = QPoint((int)(tm.x() / scale), (int)(-tm.y() / scale));
-
-
-	QList<Tile> tiles;
-	QSizeF s(rect.right() - tl.x(), rect.bottom() - tl.y());
-	for (int i = 0; i < ceil(s.width() / Tile::size()); i++)
-		for (int j = 0; j < ceil(s.height() / Tile::size()); j++)
-			tiles.append(Tile(QPoint(tile.x() + i, tile.y() + j), _zoom));
-
-	_map->loadTiles(tiles, _plot);
-
-	for (int i = 0; i < tiles.count(); i++) {
-		Tile &t = tiles[i];
-		QPoint tp(tl.x() + (t.xy().x() - tile.x()) * Tile::size(),
-		  tl.y() + (t.xy().y() - tile.y()) * Tile::size());
-		painter->drawPixmap(tp, t.pixmap());
-	}
 }
 
 void PathView::resizeEvent(QResizeEvent *event)
 {
-	Q_UNUSED(event);
+#ifdef Q_WS_MAEMO_5
+	if (_rescale)
+	{
+#endif
+	qreal scale = _map->zoom();
+	if (mapScale() != scale)
+		rescale();
 
-	if (_tracks.isEmpty() && _routes.isEmpty() && _waypoints.isEmpty())
-		return;
-
-	int zoom = scale2zoom(contentsScale());
-	if (zoom != _zoom)
-		rescale(zoom);
-
-	QPointF center = contentsCenter();
+	QPointF center = contentCenter();
 	centerOn(center);
 
-	_res = zoom2resolution(_zoom, -(center.y() * mapScale(_zoom)));
+	_res = _map->resolution(center);
 	_mapScale->setResolution(_res);
 
-	resetCachedContent();
+#ifdef Q_WS_MAEMO_5
+	}
+	else _rescale = true;
+#endif
+
+	QGraphicsView::resizeEvent(event);
 }
 
 void PathView::paintEvent(QPaintEvent *event)
@@ -736,7 +667,7 @@ void PathView::scrollContentsBy(int dx, int dy)
 	QGraphicsView::scrollContentsBy(dx, dy);
 
 	QPointF center = mapToScene(viewport()->rect().center());
-	qreal res = zoom2resolution(_zoom, -(center.y() * mapScale(_zoom)));
+	qreal res = _map->resolution(center);
 
 	if (qMax(res, _res) / qMin(res, _res) > 1.1) {
 		_mapScale->setResolution(res);
