@@ -5,19 +5,21 @@
 #include <QPen>
 #include "track.h"
 #include "pathitem.h"
+#include "units.h"
 
+class Map;
 
 class TrackItem : public PathItem
 {
 	Q_OBJECT
 
 public:
-	TrackItem(const Track &track, QGraphicsItem *parent = 0);
+	TrackItem(const Track &track, Map *map, QGraphicsItem *parent = 0);
 
-	void setUnits(enum Units units);
+	void setUnits(Units units);
 
 private:
-	QString toolTip();
+	QString toolTip(Units units);
 
 	QString _name;
 	QString _desc;
